Code generation (code\_generator package)
=========================================

Generator of dadi code
--------------------------------------------

.. automodule:: gadma.code_generator.dadi_generator
   :members:
   :undoc-members:
   :show-inheritance:

Generator of moments code
-----------------------------------------------

.. automodule:: gadma.code_generator.moments_generator
   :members:
   :undoc-members:
   :show-inheritance:
